==> apache-juneau-8.2.0-src.zip: juneau-8.2.0/juneau-core/juneau-marshall/src/main/java/org/apache/juneau/utils/Tuple2Function.java <==
// ***************************************************************************************************************************
// * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file *
// * distributed with this work for additional information regarding copyright ownership.  The ASF licenses this file        *
// * to you under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance            *
// * with the License.  You may obtain a copy of the License at                                                              *
// *                                                                                                                         *
// *  http://www.apache.org/licenses/LICENSE-2.0                                                                             *
// *                                                                                                                         *
// * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an  *
// * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the        *
// * specific language governing permissions and limitations under the License.                                              *
// ***************************************************************************************************************************
package org.apache.juneau.utils;

import java.util.function.*;

/**
 * Allows you to perform a function against 2 objects.
 *
 * <p>
 * Same as {@link BiFunction}.
 *
 * <p class='bcode w800'>
 * 	Tuple2Function&lt;A,B,R&gt; <jv>x</jv> = (<jv>a</jv>,<jv>b</jv>) -> <jsm>doSomething</jsm>(<jv>a</jv>,<jv>b</jv>);
 *
 * 	R <jv>result</jv> = <jv>x</jv>.apply(<jv>xa</jv>,<jv>xb</jv>);
 * </p>
 *
 * @param <A> Object 1 type.
 * @param <B> Object 2 type.
 * @param <R> Result type.
 */
@FunctionalInterface
public interface Tuple2Function<A,B,R> {

	@SuppressWarnings("javadoc")
	R apply(A a, B b);

	@SuppressWarnings("javadoc")
	default <V> Tuple2Function<A,B,V> andThen(Function<? super R, ? extends V> after) {
		return (A a, B b) -> after.apply(apply(a, b));
	}
}

==> apache-juneau-9.1.0-src.zip: juneau-9.1.0/juneau-core/juneau-marshall/src/main/java/org/apache/juneau/utils/Tuple2Function.java <==
// ***************************************************************************************************************************
// * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file *
// * distributed with this work for additional information regarding copyright ownership.  The ASF licenses this file        *
// * to you under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance            *
// * with the License.  You may obtain a copy of the License at                                                              *
// *                                                                                                                         *
// *  http://www.apache.org/licenses/LICENSE-2.0                                                                             *
// *                                                                                                                         *
// * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an  *
// * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the        *
// * specific language governing permissions and limitations under the License.                                              *
// ***************************************************************************************************************************
package org.apache.juneau.utils;

import java.util.function.*;

/**
 * Allows you to perform a function against 2 objects.
 *
 * <p>
 * Same as {@link BiFunction}.
 *
 * <p class='bjava'>
 * 	Tuple2Function&lt;A,B,R&gt; <jv>x</jv> = (<jv>a</jv>,<jv>b</jv>) -&gt; <jsm>doSomething</jsm>(<jv>a</jv>,<jv>b</jv>);
 *
 * 	R <jv>result</jv> = <jv>x</jv>.apply(<jv>xa</jv>,<jv>xb</jv>);
 * </p>
 *
 * <h5 class='section'>See Also:</h5><ul>
 * </ul>
 *
 * @param <A> Object 1 type.
 * @param <B> Object 2 type.
 * @param <R> Result type.
 */
@FunctionalInterface
public interface Tuple2Function<A,B,R> {

	@SuppressWarnings("javadoc")
	R apply(A a, B b);

	@SuppressWarnings("javadoc")
	default <V> Tuple2Function<A,B,V> andThen(Function<? super R, ? extends V> after) {
		return (A a, B b) -> after.apply(apply(a, b));
	}
}
